pub struct StepID {
pub module_name: String,
pub path: Option<PathBuf>,
}Expand description
Unique ID of a single step in the conversion pipeline.
Fields
module_name: StringThe name of the module used in this step.
path: Option<PathBuf>The path (input or output) used in this step.
Implementations